Crate kcr_gateway_nginx_org

Crate kcr_gateway_nginx_org 

This crate contains kube-rs compatible bindings for Kubernetes custom resources for the gateway.nginx.org group. Each binding is generated with kopium, updated and released weekly.

Available Custom Resources

gateway.nginx.org/v1alpha1

  • ClientSettingsPolicy
  • NginxGateway
  • NginxProxy
  • ObservabilityPolicy

gateway.nginx.org/v1alpha2

  • NginxProxy
  • ObservabilityPolicy

Modules

v1alpha1
v1alpha2