This crate contains kube-rs compatible bindings for Kubernetes custom resources for the gateway.nginx.org group. Each binding is generated with kopium, updated and released weekly.
Available Custom Resources
gateway.nginx.org/v1alpha1
ClientSettingsPolicyNginxGatewayNginxProxyObservabilityPolicy
gateway.nginx.org/v1alpha2
NginxProxyObservabilityPolicy